==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/inputs/TableLevelSharingPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.inputs

import com.pulumi.azurenative.synapse.inputs.TableLevelSharingPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Tables that will be included and excluded in the follower database
 * @property externalTablesToExclude List of external tables exclude from the follower database
 * @property externalTablesToInclude List of external tables to include in the follower database
 * @property materializedViewsToExclude List of materialized views exclude from the follower database
 * @property materializedViewsToInclude List of materialized views to include in the follower database
 * @property tablesToExclude List of tables to exclude from the follower database
 * @property tablesToInclude List of tables to include in the follower database
 */
public data class TableLevelSharingPropertiesArgs(
    public val externalTablesToExclude: Output<List<String>>? = null,
    public val externalTablesToInclude: Output<List<String>>? = null,
    public val materializedViewsToExclude: Output<List<String>>? = null,
    public val materializedViewsToInclude: Output<List<String>>? = null,
    public val tablesToExclude: Output<List<String>>? = null,
    public val tablesToInclude: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.synapse.inputs.TableLevelSharingPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.synapse.inputs.TableLevelSharingPropertiesArgs =
        com.pulumi.azurenative.synapse.inputs.TableLevelSharingPropertiesArgs.builder()
            .externalTablesToExclude(
                externalTablesToExclude?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            )
            .externalTablesToInclude(
                externalTablesToInclude?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            )
            .materializedViewsToExclude(
                materializedViewsToExclude?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            )
            .materializedViewsToInclude(
                materializedViewsToInclude?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            )
            .tablesToExclude(tablesToExclude?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .tablesToInclude(tablesToInclude?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [TableLevelSharingPropertiesArgs].
 */
@PulumiTagMarker
public class TableLevelSharingPropertiesArgsBuilder internal constructor() {
    private var externalTablesToExclude: Output<List<String>>? = null

    private var externalTablesToInclude: Output<List<String>>? = null

    private var materializedViewsToExclude: Output<List<String>>? = null

    private var materializedViewsToInclude: Output<List<String>>? = null

    private var tablesToExclude: Output<List<String>>? = null

    private var tablesToInclude: Output<List<String>>? = null

    /**
     * @param value List of external tables exclude from the follower database
     */
    @JvmName("rgqgjnjcixkyvvor")
    public suspend fun externalTablesToExclude(`value`: Output<List<String>>) {
        this.externalTablesToExclude = value
    }

    @JvmName("ygtusllqrowwgfon")
    public suspend fun externalTablesToExclude(vararg values: Output<String>) {
        this.externalTablesToExclude = Output.all(values.asList())
    }

    /**
     * @param values List of external tables exclude from the follower database
     */
    @JvmName("erarmocbtqipocrf")
    public suspend fun externalTablesToExclude(values: List<Output<String>>) {
        this.externalTablesToExclude = Output.all(values)
    }

    /**
     * @param value List of external tables to include in the follower database
     */
    @JvmName("jisxmyvqrqjsklvr")
    public suspend fun externalTablesToInclude(`value`: Output<List<String>>) {
        this.externalTablesToInclude = value
    }

    @JvmName("qcevxabaoneypqet")
    public suspend fun externalTablesToInclude(vararg values: Output<String>) {
        this.externalTablesToInclude = Output.all(values.asList())
    }

    /**
     * @param values List of external tables to include in the follower database
     */
    @JvmName("leokcufiaesmpbsm")
    public suspend fun externalTablesToInclude(values: List<Output<String>>) {
        this.externalTablesToInclude = Output.all(values)
    }

    /**
     * @param value List of materialized views exclude from the follower database
     */
    @JvmName("vpkvlvrkovkesodb")
    public suspend fun materializedViewsToExclude(`value`: Output<List<String>>) {
        this.materializedViewsToExclude = value
    }

    @JvmName("retyonvlvvpclsuw")
    public suspend fun materializedViewsToExclude(vararg values: Output<String>) {
        this.materializedViewsToExclude = Output.all(values.asList())
    }

    /**
     * @param values List of materialized views exclude from the follower database
     */
    @JvmName("beddycmdguakqwkb")
    public suspend fun materializedViewsToExclude(values: List<Output<String>>) {
        this.materializedViewsToExclude = Output.all(values)
    }

    /**
     * @param value List of materialized views to include in the follower database
     */
    @JvmName("orubmgyklordcmki")
    public suspend fun materializedViewsToInclude(`value`: Output<List<String>>) {
        this.materializedViewsToInclude = value
    }

    @JvmName("rkdnnpuecahnrjvm")
    public suspend fun materializedViewsToInclude(vararg values: Output<String>) {
        this.materializedViewsToInclude = Output.all(values.asList())
    }

    /**
     * @param values List of materialized views to include in the follower database
     */
    @JvmName("pdplefldtytfewvp")
    public suspend fun materializedViewsToInclude(values: List<Output<String>>) {
        this.materializedViewsToInclude = Output.all(values)
    }

    /**
     * @param value List of tables to exclude from the follower database
     */
    @JvmName("jubftjphktggllcg")
    public suspend fun tablesToExclude(`value`: Output<List<String>>) {
        this.tablesToExclude = value
    }

    @JvmName("pdbtmyydtwkexcur")
    public suspend fun tablesToExclude(vararg values: Output<String>) {
        this.tablesToExclude = Output.all(values.asList())
    }

    /**
     * @param values List of tables to exclude from the follower database
     */
    @JvmName("pkprdsllqjahbinr")
    public suspend fun tablesToExclude(values: List<Output<String>>) {
        this.tablesToExclude = Output.all(values)
    }

    /**
     * @param value List of tables to include in the follower database
     */
    @JvmName("ltgcfkxuygpkhded")
    public suspend fun tablesToInclude(`value`: Output<List<String>>) {
        this.tablesToInclude = value
    }

    @JvmName("huinakhcjxspkwuv")
    public suspend fun tablesToInclude(vararg values: Output<String>) {
        this.tablesToInclude = Output.all(values.asList())
    }

    /**
     * @param values List of tables to include in the follower database
     */
    @JvmName("djodwqbwvhvtslii")
    public suspend fun tablesToInclude(values: List<Output<String>>) {
        this.tablesToInclude = Output.all(values)
    }

    /**
     * @param value List of external tables exclude from the follower database
     */
    @JvmName("xabcnujnpyeyeqbr")
    public suspend fun externalTablesToExclude(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.externalTablesToExclude = mapped
    }

    /**
     * @param values List of external tables exclude from the follower database
     */
    @JvmName("spucelnkprssscmg")
    public suspend fun externalTablesToExclude(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.externalTablesToExclude = mapped
    }

    /**
     * @param value List of external tables to include in the follower database
     */
    @JvmName("wjnriopicghllhmy")
    public suspend fun externalTablesToInclude(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.externalTablesToInclude = mapped
    }

    /**
     * @param values List of external tables to include in the follower database
     */
    @JvmName("bixdmfjkfelsktfr")
    public suspend fun externalTablesToInclude(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.externalTablesToInclude = mapped
    }

    /**
     * @param value List of materialized views exclude from the follower database
     */
    @JvmName("pxnfjingbbvaxpwk")
    public suspend fun materializedViewsToExclude(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.materializedViewsToExclude = mapped
    }

    /**
     * @param values List of materialized views exclude from the follower database
     */
    @JvmName("bpsfoggofiywener")
    public suspend fun materializedViewsToExclude(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.materializedViewsToExclude = mapped
    }

    /**
     * @param value List of materialized views to include in the follower database
     */
    @JvmName("yulhgyaktlwbbhwc")
    public suspend fun materializedViewsToInclude(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.materializedViewsToInclude = mapped
    }

    /**
     * @param values List of materialized views to include in the follower database
     */
    @JvmName("rnhsgfcsdvmqmuxw")
    public suspend fun materializedViewsToInclude(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.materializedViewsToInclude = mapped
    }

    /**
     * @param value List of tables to exclude from the follower database
     */
    @JvmName("cwfswjvbgmnplyry")
    public suspend fun tablesToExclude(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tablesToExclude = mapped
    }

    /**
     * @param values List of tables to exclude from the follower database
     */
    @JvmName("ylpirwnexepgpqsb")
    public suspend fun tablesToExclude(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tablesToExclude = mapped
    }

    /**
     * @param value List of tables to include in the follower database
     */
    @JvmName("vlivworwpelgfxdv")
    public suspend fun tablesToInclude(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tablesToInclude = mapped
    }

    /**
     * @param values List of tables to include in the follower database
     */
    @JvmName("eopwlyqroyogrtby")
    public suspend fun tablesToInclude(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tablesToInclude = mapped
    }

    internal fun build(): TableLevelSharingPropertiesArgs = TableLevelSharingPropertiesArgs(
        externalTablesToExclude = externalTablesToExclude,
        externalTablesToInclude = externalTablesToInclude,
        materializedViewsToExclude = materializedViewsToExclude,
        materializedViewsToInclude = materializedViewsToInclude,
        tablesToExclude = tablesToExclude,
        tablesToInclude = tablesToInclude,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/inputs/TableLevelSharingPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.inputs

import com.pulumi.azurenative.synapse.inputs.TableLevelSharingPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Tables that will be included and excluded in the follower database
 * @property externalTablesToExclude List of external tables exclude from the follower database
 * @property externalTablesToInclude List of external tables to include in the follower database
 * @property materializedViewsToExclude List of materialized views exclude from the follower database
 * @property materializedViewsToInclude List of materialized views to include in the follower database
 * @property tablesToExclude List of tables to exclude from the follower database
 * @property tablesToInclude List of tables to include in the follower database
 */
public data class TableLevelSharingPropertiesArgs(
    public val externalTablesToExclude: Output<List<String>>? = null,
    public val externalTablesToInclude: Output<List<String>>? = null,
    public val materializedViewsToExclude: Output<List<String>>? = null,
    public val materializedViewsToInclude: Output<List<String>>? = null,
    public val tablesToExclude: Output<List<String>>? = null,
    public val tablesToInclude: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.synapse.inputs.TableLevelSharingPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.synapse.inputs.TableLevelSharingPropertiesArgs =
        com.pulumi.azurenative.synapse.inputs.TableLevelSharingPropertiesArgs.builder()
            .externalTablesToExclude(
                externalTablesToExclude?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            )
            .externalTablesToInclude(
                externalTablesToInclude?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            )
            .materializedViewsToExclude(
                materializedViewsToExclude?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            )
            .materializedViewsToInclude(
                materializedViewsToInclude?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            )
            .tablesToExclude(tablesToExclude?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .tablesToInclude(tablesToInclude?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [TableLevelSharingPropertiesArgs].
 */
@PulumiTagMarker
public class TableLevelSharingPropertiesArgsBuilder internal constructor() {
    private var externalTablesToExclude: Output<List<String>>? = null

    private var externalTablesToInclude: Output<List<String>>? = null

    private var materializedViewsToExclude: Output<List<String>>? = null

    private var materializedViewsToInclude: Output<List<String>>? = null

    private var tablesToExclude: Output<List<String>>? = null

    private var tablesToInclude: Output<List<String>>? = null

    /**
     * @param value List of external tables exclude from the follower database
     */
    @JvmName("smayyumdjbuewroa")
    public suspend fun externalTablesToExclude(`value`: Output<List<String>>) {
        this.externalTablesToExclude = value
    }

    @JvmName("lylmtjkbdramopeh")
    public suspend fun externalTablesToExclude(vararg values: Output<String>) {
        this.externalTablesToExclude = Output.all(values.asList())
    }

    /**
     * @param values List of external tables exclude from the follower database
     */
    @JvmName("enppypayfetrxyyk")
    public suspend fun externalTablesToExclude(values: List<Output<String>>) {
        this.externalTablesToExclude = Output.all(values)
    }

    /**
     * @param value List of external tables to include in the follower database
     */
    @JvmName("hgutcovnnbagqtdk")
    public suspend fun externalTablesToInclude(`value`: Output<List<String>>) {
        this.externalTablesToInclude = value
    }

    @JvmName("beriqjermnrymmec")
    public suspend fun externalTablesToInclude(vararg values: Output<String>) {
        this.externalTablesToInclude = Output.all(values.asList())
    }

    /**
     * @param values List of external tables to include in the follower database
     */
    @JvmName("mriujanikykdbioq")
    public suspend fun externalTablesToInclude(values: List<Output<String>>) {
        this.externalTablesToInclude = Output.all(values)
    }

    /**
     * @param value List of materialized views exclude from the follower database
     */
    @JvmName("swwvdkhngblocohw")
    public suspend fun materializedViewsToExclude(`value`: Output<List<String>>) {
        this.materializedViewsToExclude = value
    }

    @JvmName("xlnlbqayuvlfggpi")
    public suspend fun materializedViewsToExclude(vararg values: Output<String>) {
        this.materializedViewsToExclude = Output.all(values.asList())
    }

    /**
     * @param values List of materialized views exclude from the follower database
     */
    @JvmName("aqyogdpcemqkiccw")
    public suspend fun materializedViewsToExclude(values: List<Output<String>>) {
        this.materializedViewsToExclude = Output.all(values)
    }

    /**
     * @param value List of materialized views to include in the follower database
     */
    @JvmName("byfougarhiwtobdk")
    public suspend fun materializedViewsToInclude(`value`: Output<List<String>>) {
        this.materializedViewsToInclude = value
    }

    @JvmName("txgqqhjspatosqhw")
    public suspend fun materializedViewsToInclude(vararg values: Output<String>) {
        this.materializedViewsToInclude = Output.all(values.asList())
    }

    /**
     * @param values List of materialized views to include in the follower database
     */
    @JvmName("wcpyadrkqdkvmuho")
    public suspend fun materializedViewsToInclude(values: List<Output<String>>) {
        this.materializedViewsToInclude = Output.all(values)
    }

    /**
     * @param value List of tables to exclude from the follower database
     */
    @JvmName("dljbxlxnerhggkpv")
    public suspend fun tablesToExclude(`value`: Output<List<String>>) {
        this.tablesToExclude = value
    }

    @JvmName("umkxficornojeffc")
    public suspend fun tablesToExclude(vararg values: Output<String>) {
        this.tablesToExclude = Output.all(values.asList())
    }

    /**
     * @param values List of tables to exclude from the follower database
     */
    @JvmName("bcuvhjnseewksimt")
    public suspend fun tablesToExclude(values: List<Output<String>>) {
        this.tablesToExclude = Output.all(values)
    }

    /**
     * @param value List of tables to include in the follower database
     */
    @JvmName("lrepkbhmuwmgaldr")
    public suspend fun tablesToInclude(`value`: Output<List<String>>) {
        this.tablesToInclude = value
    }

    @JvmName("bdmuuuchoolxsqbj")
    public suspend fun tablesToInclude(vararg values: Output<String>) {
        this.tablesToInclude = Output.all(values.asList())
    }

    /**
     * @param values List of tables to include in the follower database
     */
    @JvmName("lguddwgkiolgghrc")
    public suspend fun tablesToInclude(values: List<Output<String>>) {
        this.tablesToInclude = Output.all(values)
    }

    /**
     * @param value List of external tables exclude from the follower database
     */
    @JvmName("hgbyalbhssbyuwnq")
    public suspend fun externalTablesToExclude(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.externalTablesToExclude = mapped
    }

    /**
     * @param values List of external tables exclude from the follower database
     */
    @JvmName("fggmltbqswqxgxit")
    public suspend fun externalTablesToExclude(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.externalTablesToExclude = mapped
    }

    /**
     * @param value List of external tables to include in the follower database
     */
    @JvmName("phglibhbqtuqkejm")
    public suspend fun externalTablesToInclude(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.externalTablesToInclude = mapped
    }

    /**
     * @param values List of external tables to include in the follower database
     */
    @JvmName("jeehyefrnlcychdj")
    public suspend fun externalTablesToInclude(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.externalTablesToInclude = mapped
    }

    /**
     * @param value List of materialized views exclude from the follower database
     */
    @JvmName("vlcddfflxxqhivov")
    public suspend fun materializedViewsToExclude(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.materializedViewsToExclude = mapped
    }

    /**
     * @param values List of materialized views exclude from the follower database
     */
    @JvmName("qxlafuyqfmwkfdyr")
    public suspend fun materializedViewsToExclude(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.materializedViewsToExclude = mapped
    }

    /**
     * @param value List of materialized views to include in the follower database
     */
    @JvmName("kyvjgfcwlfauniaw")
    public suspend fun materializedViewsToInclude(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.materializedViewsToInclude = mapped
    }

    /**
     * @param values List of materialized views to include in the follower database
     */
    @JvmName("tiahspfgquxwebuw")
    public suspend fun materializedViewsToInclude(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.materializedViewsToInclude = mapped
    }

    /**
     * @param value List of tables to exclude from the follower database
     */
    @JvmName("wxnmbxytgkjlkmnp")
    public suspend fun tablesToExclude(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tablesToExclude = mapped
    }

    /**
     * @param values List of tables to exclude from the follower database
     */
    @JvmName("jjcpqhpnimvenhfa")
    public suspend fun tablesToExclude(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tablesToExclude = mapped
    }

    /**
     * @param value List of tables to include in the follower database
     */
    @JvmName("sowpmeoitfmulyax")
    public suspend fun tablesToInclude(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tablesToInclude = mapped
    }

    /**
     * @param values List of tables to include in the follower database
     */
    @JvmName("snfifdbwhkbvwrye")
    public suspend fun tablesToInclude(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tablesToInclude = mapped
    }

    internal fun build(): TableLevelSharingPropertiesArgs = TableLevelSharingPropertiesArgs(
        externalTablesToExclude = externalTablesToExclude,
        externalTablesToInclude = externalTablesToInclude,
        materializedViewsToExclude = materializedViewsToExclude,
        materializedViewsToInclude = materializedViewsToInclude,
        tablesToExclude = tablesToExclude,
        tablesToInclude = tablesToInclude,
    )
}
